@@ -1,28 +1,28 @@
-/*************************************************************************** 
+/***************************************************************************
  *  Feed.cs
  *
  *  Copyright (C) 2007 Michael C. Urbanski
  *  Written by Mike Urbanski <michael.c.urbanski@gmail.com>
  ****************************************************************************/
 
-/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
+/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW:
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
- *  copy of this software and associated documentation files (the "Software"),  
- *  to deal in the Software without restriction, including without limitation  
- *  the rights to use, copy, modify, merge, publish, distribute, sublicense,  
- *  and/or sell copies of the Software, and to permit persons to whom the  
+ *  copy of this software and associated documentation files (the "Software"),
+ *  to deal in the Software without restriction, including without limitation
+ *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ *  and/or sell copies of the Software, and to permit persons to whom the
  *  Software is furnished to do so, subject to the following conditions:
  *
- *  The above copyright notice and this permission notice shall be included in 
+ *  The above copyright notice and this permission notice shall be included in
  *  all copies or substantial portions of the Software.
  *
- *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
- *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
- *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
- *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
- *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
- *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
+ *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+ *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  */
 
@@ -46,7 +46,7 @@ using Migo.DownloadCore;
 
 namespace Migo.Syndication
 {
-    public enum FeedAutoDownload : int 
+    public enum FeedAutoDownload : int
     {
         All = 0,
         One = 1,
@@ -56,26 +56,26 @@ namespace Migo.Syndication
     // TODO remove this, way too redundant with DownloadStatus
     public enum PodcastFeedActivity : int {
         Updating = 0,
-        UpdatePending = 1,        
+        UpdatePending = 1,
         UpdateFailed = 2,
-        ItemsDownloading = 4,        
-        ItemsQueued = 5,        
-        None = 6        
+        ItemsDownloading = 4,
+        ItemsQueued = 5,
+        None = 6
     }
-    
+
     public class FeedProvider : MigoModelProvider<Feed>
     {
         public FeedProvider (HyenaSqliteConnection connection) : base (connection, "PodcastSyndications")
         {
         }
-        
+
         protected override void CreateTable ()
         {
             base.CreateTable ();
-            
+
             CreateIndex ("PodcastSyndicationsIndex", "IsSubscribed, Title");
         }
-        
+
         protected override int ModelVersion {
             get { return 3; }
         }
@@ -87,7 +87,7 @@ namespace Migo.Syndication
             if (old_version < 2) {
                 Connection.Execute (String.Format ("UPDATE {0} SET IsSubscribed=1", TableName));
             }
-            
+
             if (old_version < 3) {
                 CreateIndex ("PodcastSyndicationsIndex", "IsSubscribed, Title");
             }
@@ -100,7 +100,7 @@ namespace Migo.Syndication
         public static FeedProvider Provider {
             get { return provider; }
         }
-        
+
         public static void Init () {
             provider = new FeedProvider (FeedsManager.Instance.Connection);
         }
@@ -111,13 +111,13 @@ namespace Migo.Syndication
         }
 
         //private bool canceled;
-        //private bool deleted; 
+        //private bool deleted;
         //private bool updating;
-        
+
         //private ManualResetEvent updatingHandle = new ManualResetEvent (true);
-        
+
         private readonly object sync = new object ();
-        
+
         private string copyright;
         private string description;
         private string image_url;
@@ -135,23 +135,25 @@ namespace Migo.Syndication
         private string title;
         private string url;
         private string keywords, category;
-        
+
 #region Database-bound Properties
 
         [DatabaseColumn ("FeedID", Constraints = DatabaseColumnConstraints.PrimaryKey)]
-        public override long DbId { 
+        public override long DbId {
             get { return dbid; }
             protected set { dbid = value; }
         }
-        
+
+        public static string UnknownPodcastTitle = Catalog.GetString ("Unknown Podcast");
+
         [DatabaseColumn]
         public string Title {
-            get { return title ?? Catalog.GetString ("Unknown Podcast"); }
+            get { return title ?? UnknownPodcastTitle; }
             set { title = value; }
         }
-        
+
         [DatabaseColumn]
-        public string Description { 
+        public string Description {
             get { return description; }
             set { description = value; }
         }
@@ -161,25 +163,25 @@ namespace Migo.Syndication
             get { return url; }
             set { url = value; }
         }
-        
+
         [DatabaseColumn]
         public string Keywords {
             get { return keywords; }
             set { keywords = value; }
         }
-        
+
         [DatabaseColumn]
         public string Category {
             get { return category; }
             set { category = value; }
         }
-        
+
         [DatabaseColumn]
-        public string Copyright { 
+        public string Copyright {
             get { return copyright; }
             set { copyright = value; }
         }
-        
+
         [DatabaseColumn]
         public string ImageUrl {
             get { return image_url; }
@@ -187,35 +189,35 @@ namespace Migo.Syndication
         }
 
         [DatabaseColumn]
-        public int UpdatePeriodMinutes { 
+        public int UpdatePeriodMinutes {
             get { return update_period_minutes; }
-            set { update_period_minutes = value; } 
+            set { update_period_minutes = value; }
         }
-        
+
         [DatabaseColumn]
-        public string Language { 
+        public string Language {
             get { return language; }
             set { language = value; }
         }
 
         [DatabaseColumn]
-        public FeedDownloadError LastDownloadError { 
+        public FeedDownloadError LastDownloadError {
             get { return lastDownloadError; }
             set { lastDownloadError = value; }
         }
-        
+
         [DatabaseColumn]
-        public DateTime LastDownloadTime { 
+        public DateTime LastDownloadTime {
             get { return last_download_time; }
             set { last_download_time = value; }
         }
-        
+
         [DatabaseColumn]
-        public string Link { 
+        public string Link {
             get { return link; }
             set { link = value; }
         }
-        
+
         //[DatabaseColumn]
         public string LocalEnclosurePath {
             get {
@@ -230,32 +232,32 @@ namespace Migo.Syndication
             get { return maxItemCount; }
             set { maxItemCount = value; }
         }
-        
+
         [DatabaseColumn]
         public DateTime PubDate {
             get { return pubDate; }
             set { pubDate = value; }
         }
-        
+
         [DatabaseColumn]
         public DateTime LastBuildDate {
             get { return last_build_date; }
             set { last_build_date = value; }
         }
-        
+
         /*private DateTime last_downloaded;
         [DatabaseColumn]
         public DateTime LastDownloaded {
             get { return last_downloaded; }
             set { last_downloaded = value; }
         }*/
-        
+
         [DatabaseColumn]
 		public FeedSyncSetting SyncSetting {
             get { return syncSetting; }
             set { syncSetting = value; }
         }
-        
+
         [DatabaseColumn]
         protected DateTime last_auto_download = DateTime.MinValue;
         public DateTime LastAutoDownload {
@@ -275,47 +277,47 @@ namespace Migo.Syndication
                 CheckForItemsToDownload ();
             }
         }
-        
+
         [DatabaseColumn("DownloadStatus")]
         private FeedDownloadStatus download_status;
-        public FeedDownloadStatus DownloadStatus { 
+        public FeedDownloadStatus DownloadStatus {
             get { return download_status; }
             set { download_status = value; }
         }
-        
+
         [DatabaseColumn("IsSubscribed")]
         private bool is_subscribed;
         public bool IsSubscribed {
             get { return is_subscribed; }
             set { is_subscribed = value; }
         }
-        
+
 #endregion
 
-#region Other Properties  
+#region Other Properties
 
         // TODO remove this, way too redundant with DownloadStatus
         /*public PodcastFeedActivity Activity {
             get { return activity; }
-            
+
                 PodcastFeedActivity ret = PodcastFeedActivity.None;
-                
+
                 if (this == All) {
                     return ret;
                 }
-                
+
                 switch (DownloadStatus) {
-                case FeedDownloadStatus.Pending: 
+                case FeedDownloadStatus.Pending:
                     ret = PodcastFeedActivity.UpdatePending;
                     break;
-                case FeedDownloadStatus.Downloading: 
+                case FeedDownloadStatus.Downloading:
                     ret = PodcastFeedActivity.Updating;
-                    break;    
-                case FeedDownloadStatus.DownloadFailed: 
+                    break;
+                case FeedDownloadStatus.DownloadFailed:
                     ret = PodcastFeedActivity.UpdateFailed;
-                    break;                         
+                    break;
                 }
-                
+
                 if (ret != PodcastFeedActivity.Updating) {
                     if (ActiveDownloadCount > 0) {
                         ret = PodcastFeedActivity.ItemsDownloading;
@@ -327,11 +329,11 @@ namespace Migo.Syndication
                 return ret;
             }
         }*/
-        
+
         public IEnumerable<FeedItem> Items {
             get {
                 if (DbId > 0) {
-                    foreach (FeedItem item in 
+                    foreach (FeedItem item in
                         FeedItem.Provider.FetchAllMatching (String.Format ("{0}.FeedID = {1} ORDER BY {0}.PubDate DESC", FeedItem.Provider.TableName, DbId)))
                     {
                         yield return item;
@@ -339,7 +341,7 @@ namespace Migo.Syndication
                 }
             }
         }
-        
+
 #endregion
 
         private static FeedManager Manager {
@@ -357,50 +359,51 @@ namespace Migo.Syndication
         public Feed ()
         {
         }
-        
+
 #endregion
 
 #region Internal Methods
-       
+
         // Removing a FeedItem means removing the downloaded file.
         /*public void Remove (FeedItem item)
         {
             if (item == null) {
                 throw new ArgumentNullException ("item");
             }
-            
-           
+
+
                 if (items.Remove (item)) {
                     inactive_items.Add (item);
                     OnFeedItemRemoved (item);
                 }
             }
         }*/
-        
+
         /*public void Remove (IEnumerable<FeedItem> itms)
         {
                 if (removedItems.Count > 0) {
                     OnItemsChanged ();
-                }     
+                }
             }
         }*/
-        
+
 #endregion
 
 #region Private Methods
-        
+
         public void SetItems (IEnumerable<FeedItem> items)
         {
             bool added_any = false;
             foreach (FeedItem item in items) {
                 added_any |= AddItem (item);
             }
-            
+
             if (added_any) {
+               Manager.OnFeedsChanged ();
                CheckForItemsToDownload ();
             }
         }
-        
+
         private bool AddItem (FeedItem item)
         {
             try {
@@ -414,21 +417,21 @@ namespace Migo.Syndication
             }
             return false;
         }
-        
+
         /*private void UpdateItems (IEnumerable<FeedItem> new_items)
         {
-            ICollection<FeedItem> tmpNew = null;         
+            ICollection<FeedItem> tmpNew = null;
             List<FeedItem> zombies = new List<FeedItem> ();
-         
+
             if (items.Count == 0 && inactive_items.Count == 0) {
                 tmpNew = new List<FeedItem> (new_items);
             } else {
                 // Get remote items that aren't in the items list
                 tmpNew = Diff (items, new_items);
-                
+
                 // Of those, remove the ones that are in our inactive list
                 tmpNew = Diff (inactive_items, tmpNew);
-                
+
                 // Get a list of inactive items that aren't in the remote list any longer
                 ICollection<FeedItem> doubleKilledZombies = Diff (
                     new_items, inactive_items
@@ -437,47 +440,47 @@ namespace Migo.Syndication
                 foreach (FeedItem zombie in doubleKilledZombies) {
                     inactive_items.Remove (zombie);
                 }
-                
-                zombies.AddRange (doubleKilledZombies);                    
-                
+
+                zombies.AddRange (doubleKilledZombies);
+
                 foreach (FeedItem fi in Diff (new_items, items)) {
                     if (fi.Enclosure != null &&
                         !String.IsNullOrEmpty (fi.Enclosure.LocalPath)) {
-                        // A hack for the podcast plugin, keeps downloaded items 
+                        // A hack for the podcast plugin, keeps downloaded items
                         // from being deleted when they are no longer in the feed.
                         continue;
                     }
-                    
+
                     zombies.Add (fi);
                 }
             }
-            
+
             if (tmpNew.Count > 0) {
-                Add (tmpNew);                
+                Add (tmpNew);
             }
-            
+
             // TODO merge...should we really be deleting these items?
             if (zombies.Count > 0) {
                 foreach (FeedItem item in zombies) {
                     if (item.Active) {
-                        zombie.Delete ();                        
-                    } 
+                        zombie.Delete ();
+                    }
                 }
-                
+
                 // TODO merge
                 //ItemsTableManager.Delete (zombies);
             }
-        }    
+        }
 
         // Written before LINQ, will update.
-        private ICollection<FeedItem> Diff (IEnumerable<FeedItem> baseSet, 
+        private ICollection<FeedItem> Diff (IEnumerable<FeedItem> baseSet,
                                             IEnumerable<FeedItem> overlay) {
             bool found;
             List<FeedItem> diff = new List<FeedItem> ();
-            
+
             foreach (FeedItem opi in overlay) {
                 found = false;
-                
+
                 foreach (FeedItem bpi in baseSet) {
                     if (opi.Title == bpi.Title &&
                         opi.Description == bpi.Description) {
@@ -486,14 +489,14 @@ namespace Migo.Syndication
                     }
                 }
 
-                if (!found) {  
+                if (!found) {
                     diff.Add (opi);
                 }
             }
 
             return diff;
         }*/
-        
+
 #endregion
 
 #region Public Methods
@@ -507,17 +510,17 @@ namespace Migo.Syndication
         public void Delete ()
         {
             Delete (true);
-            Manager.OnFeedsChanged ();                    
+            Manager.OnFeedsChanged ();
         }
-            
+
         public void Delete (bool deleteEnclosures)
         {
             lock (sync) {
                 //if (deleted)
                 //    return;
-                
+
                 //if (updating) {
-                //    Manager.CancelUpdate (this);                 
+                //    Manager.CancelUpdate (this);
                 //}
 
                 foreach (FeedItem item in Items) {
@@ -526,7 +529,7 @@ namespace Migo.Syndication
 
                 Provider.Delete (this);
             }
-            
+
             //updatingHandle.WaitOne ();
             Manager.OnFeedsChanged ();
         }
@@ -542,7 +545,7 @@ namespace Migo.Syndication
 
         public override string ToString ()
         {
-            return String.Format ("Title:  {0} - Url:  {1}", Title, Url);   
+            return String.Format ("Title:  {0} - Url:  {1}", Title, Url);
         }
 
         public void Save ()
@@ -553,7 +556,7 @@ namespace Migo.Syndication
         public void Save (bool notify)
         {
             Provider.Save (this);
-            
+
             if (LastBuildDate > LastAutoDownload) {
                 CheckForItemsToDownload ();
             }
@@ -562,17 +565,17 @@ namespace Migo.Syndication
                 Manager.OnFeedsChanged ();
             }
         }
-        
+
         private void CheckForItemsToDownload ()
         {
             if (LastDownloadError != FeedDownloadError.None || AutoDownload == FeedAutoDownload.None)
                 return;
-                
+
             bool only_first = (AutoDownload == FeedAutoDownload.One);
-            
+
             bool any = false;
             foreach (FeedItem item in Items) {
-                if (item.Enclosure != null && item.Active && 
+                if (item.Enclosure != null && item.Active &&
                     item.Enclosure.DownloadStatus != FeedDownloadStatus.Downloaded && item.PubDate > LastAutoDownload)
                 {
                     item.Enclosure.AsyncDownload ();
@@ -581,7 +584,7 @@ namespace Migo.Syndication
                         break;
                 }
             }
-            
+
             if (any) {
                 LastAutoDownload = DateTime.Now;
                 Save ();
@@ -591,15 +594,15 @@ namespace Migo.Syndication
         /*private bool SetCanceled ()
         {
             bool ret = false;
-            
+
             if (!canceled && updating) {
                 ret = canceled = true;
             }
-            
+
             return ret;
         }*/
-        
-#endregion  
+
+#endregion
 
     }
-}    
+}
